==> aroundme_0_3_3.zip: aroundme_0_3_3/www/aroundme_0_3_3/template/am_default/g_groups.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="g_groups.php" method="post" name="action">

<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "g_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table border="0" width="100%" cellspacing="4" cellpadding="0">
				<tr>
					<td class="txt_title">
						<?php echo $lang['section_action'];?><br />
						<hr />
					</td>
				</tr>
				<?php if (!isset($homepage)) { ?>
				<tr>
					<td>
						<a href="<?php echo $page_name;?>?homepage=1" class="txt_sub_menu"><?php echo $lang['href_homepage_set'];?></a><br />
					</td>
				</tr>
				<?php  } else{ ?>
				<tr>
					<td>
						<?php echo $lang['txt_homepage_current'];?><br />
					</td>
				</tr>
				<?php  } ?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table border="0" width="100%" cellspacing="4" cellpadding="0">
				<tr>
					<td class="txt_title">
						<?php echo $lang['section_search'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<input type="text" name="search_text" size="18" class="formInput" value="<?php if(isset($search)) { echo $search;}?>" /><br />
					</td>
			    </tr>

				<tr>
					<td>
						<select name="search_genre_id" class="formInput">
							<option value="0"><?php echo $lang['txt_all_genre'];?></option>
							<?php
							foreach($lang['arr_genre'] as $key => $i):
								$selected = "";
								if(isset($search_genre_id) && $search_genre_id == $key) {
									$selected = " selected";
								}
								print "<option value='" . $key . "'" . $selected . ">" . $i . "</option>";
							endforeach;
							?>
						</select>
					</td>
			    </tr>
				<tr>
					<td align="right">
						<input type="submit" name="search" value="<?php echo $lang['sub_search'];?>" class="formInput" /><br />
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<?php
		if (isset($display) && $display == "search") {
		?>
		<td width="570" valign="top">

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_search_results'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if ($search_results) {
				foreach($search_results as $key => $i):
				?>

			    <tr>
					<td>
						<?php
						if (isset($i['image']['image_id'])) {
						?>
							<img align="left" src="get_image.php?img=<?php echo $i['image']['image'];?>" border="0" class="picture" alt="<?php echo $i['image']['image_title'];?>" />
						<?
						}
						?>
						<a href="g_group.php?group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a><br />
					</td>
			    </tr>
				<tr>
					<td>
						<?php echo $i['group_synopsis'];?><br />
						<p class="txt_footer">
						<?php echo $lang['txt_recommended_age'];?>:
						<?
						if ($i['group_from_age'] && $i['group_to_age']) {
						    echo $i['group_from_age'] . "/" . $i['group_to_age'];
						}
						else if ($i['group_from_age'] && !$i['group_to_age']) {
							echo $lang['txt_age_from'] . " " . $i['group_from_age'];
						}
						else if (!$i['group_from_age'] && $i['group_to_age']) {
							echo $lang['txt_age_upto'] . " " . $i['group_to_age'];
						}
						else {
							echo $lang['txt_age_all'];
						}
						?>,
						<?php echo $lang['txt_genre'];?>: <?if (isset($i['genre_id'])) { echo $lang['arr_genre'][$i['genre_id']];}?><br />

					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_search_results'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>
		</td>

		<?php
		}
		elseif (isset($display) && $display == "mygroups") {
		?>

		<td width="570" valign="top">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_my_groups'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($my_groups[0])) {
				foreach($my_groups as $key => $i):
				?>

			    <tr>
					<td>
						<?php
						if (isset($i['image']['image_id'])) {
						?>
							<img align="left" src="get_image.php?img=<?php echo $i['image']['image'];?>" border="0" class="picture" alt="<?php echo $i['image']['image_title'];?>" />
						<?
						}
						?>
						<a href="g_group.php?group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a><br />
					</td>
			    </tr>
				<tr>
					<td>
						<?php echo $i['group_synopsis'];?><br />
						<span class="txt_footer">
						<?php
						echo $lang['txt_genre'];?>: <?if (isset($i['genre_id'])) { echo $lang['arr_genre'][$i['genre_id']];}?>
						,
						<?php echo $lang['txt_group_type'];?>: <?if (isset($i['group_type'])) { echo $lang['arr_group_type'][$i['group_type']];}?><br />
						</span>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_groups'];?>
						<br />
					</td>
				</tr>
				<?php }?>
			</table>
		</td>

		<?php
		}
		elseif (isset($display) && $display == "discussions") {
		?>

		<td width="370" valign="top">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['txt_recommended'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($discussions_recommended[0])) {
				foreach($discussions_recommended as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="g_forum_subject.php?group_id=<?php echo $i['group_id'];?>&amp;topic_id=<?php echo $i['topic_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_title'];?></a><br />
						<span class="txt_footer"><?php echo dots(200,$i['display_subject_body']);?></span><br />
					</td>
			    </tr>
				<?if (isset($i['poll'])) {?>
				<tr>
					<td align="right">
						<?php
						include $templatePath . "poll.inc.tpl.php";
						?>
					</td>
				</tr>
				<?php
				}
				endforeach;
				} else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_subjects'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>
		</td>

		<td width="20">&nbsp;</td>

		<td width="180" valign="top">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['txt_latest'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($discussions_latest[0])) {
				foreach($discussions_latest as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="g_forum_subject.php?group_id=<?php echo $i['group_id'];?>&amp;topic_id=<?php echo $i['topic_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_title'];?></a><br />
						<span class="txt_footer"><?php echo dots(200,$i['display_subject_body']);?></span><br />
					</td>
			    </tr>
				<?if (isset($i['poll'])) {?>
				<tr>
					<td>
						<?php
						include $templatePath . "poll.inc.tpl.php";
						?>
					</td>
				</tr>
				<?php
				}
				endforeach;
				} else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_subjects'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>
		</td>

		<?php
		}
		else {
		?>

		<td width="360" valign="top">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="3" class="txt_title" align="right">
						<?php echo $lang['txt_featured'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($groups_featured[0])) {
				foreach($groups_featured as $key => $i):
				?>
				<tr>
					<td>
						<img align="left" src="get_image.php?img=<?php echo $i['image']['image'];?>" border="0" class="picture" alt="<?php echo $i['image']['image_title'];?>" />
					</td>
					<td valign="top">
						<a href="g_group.php?group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a><br />
						<span class="txt_footer"><?php echo $i['group_create_datetime'];?></span><br />
						<span class="txt_footer"><?php echo $i['group_synopsis'];?></span><br />
						<p class="txt_footer">
						<?php echo $lang['txt_recommended_age'];?>:
						<?
						if ($i['group_from_age'] && $i['group_to_age']) {
						    echo $i['group_from_age'] . "/" . $i['group_to_age'];
						}
						else if ($i['group_from_age'] && !$i['group_to_age']) {
							echo $lang['txt_age_from'] . " " . $i['group_from_age'];
						}
						else if (!$i['group_from_age'] && $i['group_to_age']) {
							echo $lang['txt_age_upto'] . " " . $i['group_to_age'];
						}
						else {
							echo $lang['txt_age_all'];
						}
						?>,
						<?php echo $lang['txt_genre'];?>: <?if (isset($i['genre_id'])) { echo $lang['arr_genre'][$i['genre_id']];}?>
						,
						<?php echo $lang['txt_group_type'];?>: <?if (isset($i['group_type'])) { echo $lang['arr_group_type'][$i['group_type']];}?><br />
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_groups'];?>
						<br />
					</td>
				</tr>
				<?php }?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_latest_groups'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($latest_groups[0])) {
				foreach($latest_groups as $key => $i):
				?>

			    <tr>
					<td width="60%">
						<?php
						if (isset($i['image']['image_id'])) {
						?>
							<img align="left" src="get_image.php?img=<?php echo $i['image']['image'];?>" border="0" class="picture" alt="<?php echo $i['image']['image_title'];?>" />
						<?
						}
						?>
						<a href="g_group.php?group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a><br />
						<?php echo $i['group_synopsis'];?><br />
						<p class="txt_footer">
						<?php echo $lang['txt_recommended_age'];?>:
						<?
						if ($i['group_from_age'] && $i['group_to_age']) {
						    echo $i['group_from_age'] . "/" . $i['group_to_age'];
						}
						else if ($i['group_from_age'] && !$i['group_to_age']) {
							echo $lang['txt_age_from'] . " " . $i['group_from_age'];
						}
						else if (!$i['group_from_age'] && $i['group_to_age']) {
							echo $lang['txt_age_upto'] . " " . $i['group_to_age'];
						}
						else {
							echo $lang['txt_age_all'];
						}
						?>,
						<?php echo $lang['txt_genre'];?>: <?if (isset($i['genre_id'])) { echo $lang['arr_genre'][$i['genre_id']];}?>
						,
						<?php echo $lang['txt_group_type'];?>: <?if (isset($i['group_type'])) { echo $lang['arr_group_type'][$i['group_type']];}?><br />

					</td>
			    </tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_groups'];?>
						<br />
					</td>
				</tr>
				<?php }?>
			</table>
		</td>

		<td width="20">&nbsp;</td>

		<td width="180" valign="top">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['txt_recommended'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($recommended_groups[0])) {
				foreach($recommended_groups as $key => $i):
				?>

			    <tr>
					<td class="txt_footer">
						<a href="g_group.php?group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a><br />
						<?php echo dots(80, $i['group_synopsis']);?>
					</td>
			    </tr>
				<tr>
					<td class="txt_footer" align="right">
						<?php echo $lang['txt_recommended_age'];?>:
						<?
						if ($i['group_from_age'] && $i['group_to_age']) {
						    echo $i['group_from_age'] . "/" . $i['group_to_age'];
						}
						else if ($i['group_from_age'] && !$i['group_to_age']) {
							echo $lang['txt_age_from'] . " " . $i['group_from_age'];
						}
						else if (!$i['group_from_age'] && $i['group_to_age']) {
							echo $lang['txt_age_upto'] . " " . $i['group_to_age'];
						}
						else {
							echo $lang['txt_age_all'];
						}
						?><br />
						<?php echo $lang['txt_genre'];?>: <?if (isset($i['genre_id'])) { echo $lang['arr_genre'][$i['genre_id']];}?><br />
					</td>
			    </tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_groups'];?>
						<br />
					</td>
				</tr>
				<?php }?>
			</table>

		<?php }?>
	</tr>
</table>
</form>

==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/g_groups.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="g_groups.php" method="post" name="action">

<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "g_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table border="0" width="100%" cellspacing="4" cellpadding="0">
				<tr>
					<td class="txt_title">
						<?php echo $lang['section_search'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<input type="text" name="search_text" size="18" class="formInput" value="<?php if(isset($search)) { echo $search;}?>" /><br />
					</td>
			    </tr>

				<tr>
					<td>
						<select name="search_genre_id" class="formInput">
							<option value="0"><?php echo $lang['txt_all_genre'];?></option>
							<?php
							foreach($lang['arr_genre'] as $key => $i):
								$selected = "";
								if(isset($search_genre_id) && $search_genre_id == $key) {
									$selected = " selected";
								}
								print "<option value='" . $key . "'" . $selected . ">" . $i . "</option>";
							endforeach;
							?>
						</select>
					</td>
			    </tr>
				<tr>
					<td align="right">
						<input type="submit" name="search" value="<?php echo $lang['sub_search'];?>" class="formInput" /><br />
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="570" valign="top">
			<?php
			if (isset($display) && $display == "search") {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right" colspan="2">
						<?php echo $lang['hdr_search_results'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($search_results[0])) {
				foreach($search_results as $key => $i):
				?>
			    <tr>
					<td>
						<a href="g_group.php?group_id=<?php echo $i['group_id'];?>"><img align="left" src="get_file.php?file=<?php echo $i['image']['file'];?>" class="picture_left" alt="<?php echo $i['image']['file_title'];?>" /></a>
					</td>
					<td>
						<a href="g_group.php?group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a><br />
						<?php echo $i['group_synopsis'];?><br />
						<p class="txt_footer">
						<?php echo $lang['txt_recommended_age'];?>:
						<?
						if ($i['group_from_age'] && $i['group_to_age']) {
						    echo $i['group_from_age'] . "/" . $i['group_to_age'];
						}
						else if ($i['group_from_age'] && !$i['group_to_age']) {
							echo $lang['txt_age_from'] . " " . $i['group_from_age'];
						}
						else if (!$i['group_from_age'] && $i['group_to_age']) {
							echo $lang['txt_age_upto'] . " " . $i['group_to_age'];
						}
						else {
							echo $lang['txt_age_all'];
						}
						?>
						<br />
						<?php echo $lang['txt_genre'];?>: <?if (isset($i['genre_id'])) { echo $lang['arr_genre'][$i['genre_id']];}?><br />
						</p>
					</td>
				</tr>
				<tr>
					<td colspan="2">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td colspan="2">
						<?php echo $lang['err_no_search_results'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>
			<?php
			}
			elseif (isset($display) && $display == "mygroups") {
			?>

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right" colspan="2">
						<?php echo $lang['hdr_my_groups'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($my_groups)) {
				foreach($my_groups as $key => $i):
				?>
				 <tr>
					<td>
						<a href="g_group.php?group_id=<?php echo $i['group_id'];?>"><img align="left" src="get_file.php?file=<?php echo $i['image']['file'];?>" class="picture_left" alt="<?php echo $i['image']['file_title'];?>" /></a>
						<a href="g_group.php?group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a><br />
						<?php echo $i['group_synopsis'];?><br />
						<p class="txt_footer">
						<?php echo $lang['txt_recommended_age'];?>:
						<?
						if ($i['group_from_age'] && $i['group_to_age']) {
						    echo $i['group_from_age'] . "/" . $i['group_to_age'];
						}
						else if ($i['group_from_age'] && !$i['group_to_age']) {
							echo $lang['txt_age_from'] . " " . $i['group_from_age'];
						}
						else if (!$i['group_from_age'] && $i['group_to_age']) {
							echo $lang['txt_age_upto'] . " " . $i['group_to_age'];
						}
						else {
							echo $lang['txt_age_all'];
						}
						?>
						<br />
						<?php echo $lang['txt_genre'];?>: <?if (isset($i['genre_id'])) { echo $lang['arr_genre'][$i['genre_id']];}?><br />
						</p>
					</td>
				</tr>
				<tr>
					<td colspan="2">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td colspan="2">
						<?php echo $lang['err_no_groups'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>

			<?php
			}
			else {
			?>

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right" colspan="2">
						<?php echo $lang['hdr_latest_groups'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($latest_groups)) {
				foreach($latest_groups as $key => $i):
				?>
				 <tr>
					<td valigh="top">
						<a href="g_group.php?group_id=<?php echo $i['group_id'];?>"><img align="left" src="get_file.php?file=<?php echo $i['image']['file'];?>" class="picture_left" alt="<?php echo $i['image']['file_title'];?>" /></a>
						<a href="g_group.php?group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a><br />
						<?php echo $i['group_synopsis'];?><br />
						<p class="txt_footer">
						<?php echo $lang['txt_recommended_age'];?>:
						<?
						if ($i['group_from_age'] && $i['group_to_age']) {
						    echo $i['group_from_age'] . "/" . $i['group_to_age'];
						}
						else if ($i['group_from_age'] && !$i['group_to_age']) {
							echo $lang['txt_age_from'] . " " . $i['group_from_age'];
						}
						else if (!$i['group_from_age'] && $i['group_to_age']) {
							echo $lang['txt_age_upto'] . " " . $i['group_to_age'];
						}
						else {
							echo $lang['txt_age_all'];
						}
						?>
						<br />
						<?php echo $lang['txt_genre'];?>: <?if (isset($i['genre_id'])) { echo $lang['arr_genre'][$i['genre_id']];}?><br />
						</p>
					</td>
				</tr>
				<tr>
					<td colspan="2">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td colspan="2">
						<?php echo $lang['err_no_groups'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>
		</td>
		<?php }?>
	</tr>
</table>
</form>
